/* ======================================================== */
/*                                                          */
/*                    HW_MIK                                */
/*                                                          */
/* ======================================================== */ 

/* Pomocne procedury pro ovladani hardware MIK552           */
   

/* --------------------------------------------------------- */

#pragma INTVECTOR(0x8000)

#include	<REG552.H>
#include	"NoICE_demo.h"
#include	"HW_MIK.h"

/* --------------------------------------------------------- */

/* --- Promenne pro modul HW_MIK. V jinych modulech musi --- */
/* --- byt definovana jako EXTRN promenna timeout_label. --- */

unsigned int data	timeout_counter;	/* citac timeoutu */
unsigned int data	timeout_limit;		/* delka timeoutu v ms */
unsigned int data	wait_limit;			/* delka cekani v ms */
unsigned int data	wait_counter;		/* citac pro wait */

bit data			tx_empty;

extern bit data				send_string_ready;
extern unsigned int data	send_string_ptr;	/* pointer do vysilaciho bufferu */
/*extern unsigned char code	send_string[];*/		/* vysilaci buffer pro send_log */
extern unsigned char code	* data send_string;		/* vysilaci buffer pro send_log */

bit data			go_timeout;			/* spusteni timeoutu */
bit data			i2c_go_timeout;		/* spusteni timeoutu */
bit data			timeout_label;		/* nastavi se pri timeoutu */
bit data			wait_label;			/* nastaven dokud se ceka */
bit data			i2c_timeout_label;	/* nastavi se pri timeoutu */

unsigned char data	stack_ptr;			/* stack pointer pro sledovani */

/* =========== CASOVACE + SCA ===================== */


/* ------------ init_serial ----------------------- */

/* inicializace seriove linky 8051                  */
/* Pro 8051 se musi pouzit casovac 1 v MODE 2       */
/* Casovani je nastaveno pro 11.0592 MHz / 9600 Bd. */

void init_serial(void) {

	/* nastaveni timeru 1 */

	TR1 = OFF;
	TMOD = (TMOD & 0x0F) | 0x20;	/* timer 1 je 8 b. samoplnici  */
	ET1 = 0;						/* zakazano prerus. casovace 1 */
	TL1 = T1_9600;					/* konstanta pro 9600 Bd       */
	TH1 = T1_9600;					/* T1 je 8 bit. samoplnici     */
	TR1 = ON;						/* uz se pocita                */

	S0CON = 0x50;					/* mode 1, Rx enable */
	REN = ON;						/* jeste jedno povoleni */

	TI = OFF;						/* Tx mimo provoz */
	RI = OFF;						/* nic nebylo prijato */
	tx_empty = ON;

	/* nastaveni preruseni (globalne se povoli jinde ) */
	ES0 = ON;						/* povoleno */

}

/* ------------ serial_int ------------------------------- */

/* Obsluha preruseni od prijmu seriove linky */ 

void serial_int(void) interrupt 4 /* using 1 */ {

	/* je to od prijimace? */
	if(RI) {
	
		RI = OFF;
		
	}
	
	/* ------ konec zpracovani RI, nasleduje TI ------ */


	/* je to od vysilace */
	if(TI) {
		
		TI = OFF;
		tx_empty = ON;
		if(send_string_ready) {
			if(send_string[send_string_ptr] != 0) {
				S0BUF = send_string[send_string_ptr++];
				tx_empty = OFF;			/* vysilac byl naplnen */
			}
			else {						/* konec textu */
				send_string_ptr = 0;	/* nastaveni na zacatek */
				send_string_ready = OFF;
			}
		}
		
	}
	
}

/* ------------ init_timer_0 ----------------------------- */

/* Timer 0 je 16 bitovy pro ruzne casovani - perioda 1 ms. */   

void init_timer_0(void) {

	TR0 = OFF;
	/* nastaveni casovace 0 na preruseni po 0.001 sec */
	TL0 = TL0_001;
	TH0 = TH0_001;

	/* nastavenni dalsich potrebnych registru */
	TMOD = (TMOD & 0xF0) | 0x01;	/* Timer 0 je 16 bitovy */
	TF0 = OFF;
	ET0 = ON;						/* ma povoleno preruseni */
	
	TR0 = ON;						/* povoleno citani */

}

/* ------------ init_timer_1 ----------------------------- */

/* Timer 1 je 16 bitovy pro ruzne casovani - perioda 50 ms. */
/* ! ! ! NESMI se pouzit soucasne se seriovou linkou ! ! !  */
/*       ^^^^^                                              */   

void init_timer_1(void) {

	TR1 = OFF;
	/* nastaveni casovace 1 na preruseni po 0.050 sec */
	TL1 = TL1_050;
	TH1 = TH1_050;

	/* nastavenni dalsich potrebnych registru */
	TMOD = (TMOD & 0x0F) | 0x10;	/* Timer 1 je 16 bitovy */
	TF1 = OFF;
	ET1 = ON;						/* ma povoleno preruseni */
	
	TR1 = ON;						/* povoleno citani */

}

/* ------------ timer0_int ---------------------------- */

/* Preruseni po 0.001 sec.                              */
/* Vypocet = MAX 50 us                                  */

void timer0_int(void) interrupt 1 /* using 1 */ {

	TR0 = OFF;
	
	/* nastaveni casovace 0 na preruseni po 0.001 sec */
	TL0 = TL0_001;
	TH0 = TH0_001;
	TF0 = OFF;
	TR0 = ON;

	/* citac pro proceduru wait */
	if(wait_label) {
		if(++wait_counter > wait_limit) {
			wait_counter = 0;
			wait_label = OFF;
		}
	}

	/* citac pro vseobecne timeouty (napr. displej) */
	if(go_timeout) {
		if(++timeout_counter > timeout_limit) {
			timeout_counter = 0;
			go_timeout = OFF;
			timeout_label = ON;	/* timeout */
		}
	}

	stack_ptr = SP;			/* sledovani vyuziti stacku */

}

/* ------------ timer1_int ---------------------------- */

/* Preruseni po 0.050 sec.                              */

void timer1_int(void) interrupt 3 /* using 1 */ {

	TR1 = OFF;
	
	/* nastaveni casovace 1 na preruseni po 0.050 sec */
	TL1 = TL1_050;
	TH1 = TH1_050;
	TF1 = OFF;
	TR1 = ON;


}

/* ------------ wait ----------------------------------- */

/* Ceka n_ms milisekund + doba od inicializace k prvnimu */
/* preruseni od T0.                                      */

void wait(unsigned int n_ms) {

	wait_counter = 0;
	wait_limit = n_ms;
	wait_label = ON;
	while(wait_label) {};	/* shodi se pri preruseni od T0 */

}

/* ------------ start_timeout -------------------------- */

/* Ceka delay ms, potom nastavi timeout_label.           */

void start_timeout(unsigned int delay) {

	go_timeout = OFF;
	timeout_label = OFF;
	timeout_limit = delay;
	timeout_counter = 0;
	
	go_timeout = ON;
	
}

/* ------------ stop_timeout --------------------------- */

/* Zastavi mereni timeoutu.                              */

void stop_timeout(void) {

	go_timeout = OFF;
	
}


/* +++++++++++++++++++++++++++++++++++++++++++++++++++++ */	


/* =============== END HW_MIK ========================== */ 





























































































